@@ -16,6 +16,7 @@ from q2_types.feature_table import (FeatureTable, Frequency,
 from q2_types.distance_matrix import DistanceMatrix
 
 import q2_phylogeny
+import q2_phylogeny._examples as ex
 
 _RAXML_MODEL_OPT = ['GTRGAMMA', 'GTRGAMMAI', 'GTRCAT', 'GTRCATI']
 _RAXML_VERSION_OPT = ['Standard', 'SSE3', 'AVX2']
@@ -289,7 +290,6 @@ plugin.methods.register_function(
                  '(http://www.iqtree.org/) with automatic model selection.'),
     citations=[citations['Minh2020iqtree'],
                citations['Kalyaanamoorthy2017modelfinder']],
-    deprecated=True
 )
 
 plugin.methods.register_function(
@@ -399,7 +399,6 @@ plugin.methods.register_function(
                citations['Kalyaanamoorthy2017modelfinder'],
                citations['Minh2013ultrafastbootstrap'],
                citations['Hoang2017ultrafastbootstrap2']],
-    deprecated=True
 )
 
 T1 = TypeMatch([Frequency, RelativeFrequency, PresenceAbsence])
@@ -556,7 +555,11 @@ plugin.pipelines.register_function(
                  'masked MAFFT alignment from q2-alignment methods, and both '
                  'the rooted and unrooted phylogenies from q2-phylogeny '
                  'methods.'
-                 )
+                 ),
+    examples={
+        'align_to_tree_mafft_fasttree':
+        ex.phylogeny_align_to_tree_mafft_fasttree,
+    }
 )
 
 plugin.pipelines.register_function(
@@ -648,7 +651,6 @@ plugin.pipelines.register_function(
                  'q2-alignment methods, and both the rooted and unrooted '
                  'phylogenies from q2-phylogeny methods.'
                  ),
-    deprecated=True
 )
 
 plugin.pipelines.register_function(
